@@ -182,6 +182,10 @@ char *argv[];
     qprint ("growing continents...\n");
     grow_continents();
   } while (status && ++i < NUMTRIES); 
+  if (status) {
+	  fputs("ERROR: World not large enough to hold continents\n", stderr);
+	  exit(1);
+  }
   qprint ("growing islands:");
   grow_islands();
   qprint ("\nelevating land...\n");
