@@ -117,12 +117,12 @@ bomb()
 	tech = 0;
 	mission_flags |= P_X;		/* stealth (shhh) */
 	mission_flags |= P_H; /* gets turned off if not all choppers */
-	mission_flags = pln_arm(&bomb_list, mission, ip, 0, mission_flags, &tech);
+	mission_flags = pln_arm(&bomb_list, 2*ap_to_target, mission, ip, 0, mission_flags, &tech);
 	if (QEMPTY(&bomb_list)) {
 		pr("No planes could be equipped for the mission.\n");
 		return RET_FAIL;
 	}
-	mission_flags = pln_arm(&esc_list, mission, ip,P_F|P_ESC,mission_flags,&tech);
+	mission_flags = pln_arm(&esc_list, 2*ap_to_target, mission, ip,P_F|P_ESC,mission_flags,&tech);
 	ac_encounter(&bomb_list,&esc_list,ax,ay,flightpath,mission_flags,0);
 	if (QEMPTY(&bomb_list)) {
 		pr("No planes got through fighter defenses\n");
