@@ -420,7 +420,7 @@ att_abort(combat_mode, off, def)
 		(sect.sct_oldown != player->cnum) && (issneak != SITZKRIEG) &&
 		(issneak != MOBILIZATION)) {
 		pr("You're not at war with them!\n");
-		if (!confirm("Do you really want to sneak attack [yn]? ")){
+		if (!confirm("Do you really want to sneak attack (it will cost you $5000) [yn]? ")){
 			pr("Sneak attack cancelled!\n");
 			return abort_attack();
 		}
@@ -1345,8 +1345,9 @@ att_reacting_units(def, list, a_spy, d_spyp, ototal)
 
 		dist = mapdist(land.lnd_x,land.lnd_y,def->x,def->y);
 
+		getsect(land.lnd_x, land.lnd_y, &sect);
 		/* Units on efficient headquarters can react 1 farther */
-		if ((def->sct_type == SCT_HEADQ) && (def->eff >= 60))
+		if ((sect.sct_type == SCT_HEADQ) && (sect.sct_effic >= 60))
 			radius=land.lnd_rad_max+1;
 		else
 			radius=land.lnd_rad_max;
@@ -1357,7 +1358,6 @@ att_reacting_units(def, list, a_spy, d_spyp, ototal)
 		if (dist > radius)
 			continue;
 
-		getsect(land.lnd_x, land.lnd_y, &sect);
 		getsect(def->x, def->y, &dsect);
 		if (!(p = (s_char *)BestLandPath(buf, &sect, &dsect, &move_cost)))
 			continue;
