@@ -377,6 +377,19 @@ shp_count(list, wantflags, nowantflags)
 	return count;
 }
 
+static int
+shp_damage_one(mlp, dam)
+	struct	mlist *mlp;
+	int dam;
+{
+	shipdamage(&mlp->ship, dam);
+	putship(mlp->ship.shp_uid, &mlp->ship);
+	if (!mlp->ship.shp_own) {
+		remque((struct qelem *)mlp);
+		free((s_char *)mlp);
+	}
+}
+
 static int
 shp_damage(list, totdam, wantflags, nowantflags)
 	struct	qelem	*list;
@@ -400,12 +413,7 @@ shp_damage(list, totdam, wantflags, nowantflags)
 			continue;
 		if (nowantflags && mlp->mcp->m_flags & nowantflags)
 			continue;
-		shipdamage(&mlp->ship, dam);
-		putship(mlp->ship.shp_uid, &mlp->ship);
-		if (!mlp->ship.shp_own) {
-			remque(qp);
-			free((s_char *)qp);
-		}
+		shp_damage_one(mlp, dam);
 	}
 	return dam;
 }
@@ -432,6 +440,37 @@ shp_contains(list, wantflags, nowantflags)
 	return 0;
 }
 
+static struct mlist *
+most_valuable_ship(list)
+	struct qelem *list;
+{
+	struct	qelem *qp;
+	struct	qelem *next;
+	struct	mlist *mlp;
+	struct	mlist *mvs = 0;
+
+	for (qp = list->q_back; qp != list; qp = next) {
+		next = qp->q_back;
+		mlp = (struct mlist *) qp;
+		if (mlp->mcp->m_flags & M_SUB)
+			continue;
+		if (!mlp->mcp->m_nxlight &&
+		    !mlp->mcp->m_nchoppers &&
+		    mlp->mcp->m_cost < 1000 &&
+		    !mlp->mcp->m_nplanes &&
+		    !mlp->mcp->m_nland)
+			continue;
+		if (!mvs) {
+			mvs = mlp;
+			continue;
+		}
+		if (mlp->mcp->m_cost * mlp->ship.shp_effic >
+		    mvs->mcp->m_cost * mvs->ship.shp_effic)
+			mvs = mlp;
+	}
+	return mvs;
+}
+
 static int shp_easiest_target(list, wantflags, nowantflags)
 	struct	qelem	*list;
 	int	wantflags, nowantflags;
@@ -459,29 +498,31 @@ static int shp_easiest_target(list, wantflags, nowantflags)
 }
 
 static int
-shp_missile_interdiction(list, newx, newy, what, victim)
+shp_missile_interdiction(list, newx, newy, victim)
 	struct	qelem *list;
 	coord	newx, newy;
-	s_char	*what;
 	natid	victim;
 {
         int     dam;
 	int	twotries;
 	int	stopping = 0;
 	struct	qelem msl_list, *qp, *newqp;
+	struct	mlist *mvs;
+	s_char	what[512];
 
 	msl_sel(&msl_list, newx, newy, victim, P_T|P_MAR, 0, MI_INTERDICT);
 
 	twotries = 0;
-	while (!QEMPTY(&msl_list) && shp_contains(list,0,M_SUB)) {
+	while (!QEMPTY(&msl_list) && (mvs = most_valuable_ship(list))) {
+		sprintf(what, "%s", prship(&mvs->ship));
 		dam = msl_launch_mindam(&msl_list, newx, newy,
-					shp_easiest_target(list, 0, M_SUB),
+					shp_hardtarget(&mvs->ship),
 					EF_SHIP,
-					shp_count(list, 0, M_SUB),
+					1,
 					what, victim, MI_INTERDICT);
 		if (dam) {
-			mpr(victim, "missile interdiction mission does %d damage!\n", dam);
-			shp_damage(list, dam, 0, M_SUB);
+			mpr(victim, "missile interdiction mission does %d damage to %s!\n", dam, what);
+			shp_damage_one(mvs, dam);
 			twotries = 0;
 			stopping |= 1;
 		} else if (++twotries >= 2) {
@@ -645,8 +686,8 @@ shp_interdict(list, newx, newy, victim)
 		stopping |= shp_fort_interdiction(list, newx, newy, victim);
 		if (shp_contains(list, 0, M_SUB)) {
 			stopping |= shp_damage(list, unit_interdict(newx,newy,victim,"ships", shp_easiest_target(list, 0, M_SUB), MI_INTERDICT), 0, M_SUB);
-			if (shp_contains(list, 0, M_SUB)) {
-				stopping |= shp_missile_interdiction(list,newx,newy,"ships",victim);
+			if (most_valuable_ship(list)) {
+				stopping |= shp_missile_interdiction(list,newx,newy,victim);
 			}
 		}
 	}
@@ -933,13 +974,17 @@ shp_missdef(sp, victim)
 	sprintf(buf, "%s", prship(&mlp->ship));
 		
 	eff = sp->shp_effic;
-	shp_missile_interdiction(&list, sp->shp_x, sp->shp_y, buf,sp->shp_own);
-	getship(sp->shp_uid, sp);
+	if (most_valuable_ship(&list)) {
+		shp_missile_interdiction(&list, sp->shp_x, sp->shp_y, sp->shp_own);
+		getship(sp->shp_uid, sp);
 
-	if (!sp->shp_own) {
-		wu(0, victim, "missiles launched in defense did 100%% damage to %s\n", buf);
-		wu(0, victim, "%s sunk!\n", buf);
-	} else if (eff > 0 && sp->shp_effic < eff) {
-		wu(0, victim, "missiles launched in defense did %d%% damage to %s\n", 100*(eff - sp->shp_effic)/eff, buf);
+		if (!sp->shp_own) {
+			wu(0, victim, "missiles launched in defense did 100%% damage to %s\n", buf);
+			wu(0, victim, "%s sunk!\n", buf);
+		} else if (eff > 0 && sp->shp_effic < eff) {
+			wu(0, victim, "missiles launched in defense did %d%% damage to %s\n", 100*(eff - sp->shp_effic)/eff, buf);
+		}
 	}
+	if (!QEMPTY(&list))
+		free(mlp);
 }
